@@ -37,7 +37,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 For more information, please refer to <https://unlicense.org>
 """
 # pylint: disable=C0103  # Aligning method names to API operation IDs
-from ._util import service_request, generate_error_result, force_default, args_to_params
+from ._util import generate_error_result, force_default, args_to_params, process_service_request, handle_single_argument
 from ._service_class import ServiceClass
 from ._endpoint._hosts import _hosts_endpoints as Endpoints
 
@@ -45,10 +45,12 @@ from ._endpoint._hosts import _hosts_endpoints as Endpoints
 class Hosts(ServiceClass):
     """
     The only requirement to instantiate an instance of this class
-    is a valid token provided by the Falcon API SDK OAuth2 class.
+    is a valid token provided by the Falcon API SDK OAuth2 class, an
+    authorization object (oauth2.py) or a credential dictionary with
+    client_id and client_secret containing valid API credentials.
     """
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def PerformActionV2(self: object, body: dict, parameters: dict = None, **kwargs) -> dict:
+    def perform_action(self: object, body: dict, parameters: dict = None, **kwargs) -> dict:
         """
         Take various actions on the hosts in your environment.
         Contain or lift containment on a host. Delete or restore a host.
@@ -56,37 +58,30 @@ class Hosts(ServiceClass):
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/PerformActionV2
         _allowed_actions = ['contain', 'lift_containment', 'hide_host', 'unhide_host']
         operation_id = "PerformActionV2"
-        target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}"
-        header_payload = self.headers
-        body_payload = body
         parameter_payload = args_to_params(parameters, kwargs, Endpoints, operation_id)
-        if "action_name" not in parameter_payload:
-            parameter_payload["action_name"] = "Not Specified"
+        action_name = parameter_payload.get("action_name", "Not Specified")
         # Only process allowed actions
-        if parameter_payload["action_name"].lower() in _allowed_actions:
-            returned = service_request(caller=self,
-                                       method="POST",
-                                       endpoint=target_url,
-                                       body=body_payload,
-                                       params=parameter_payload,
-                                       headers=header_payload,
-                                       verify=self.ssl_verify
-                                       )
+        if action_name.lower() in _allowed_actions:
+            returned = process_service_request(
+                calling_object=self,
+                endpoints=Endpoints,
+                operation_id=operation_id,
+                body=body,
+                keywords=kwargs,
+                params=parameters
+                )
         else:
             returned = generate_error_result("Invalid value specified for action_name parameter.")
 
         return returned
 
-    def UpdateDeviceTags(self: object, action_name: str, ids: list or str, tags: list or str) -> dict:
+    def update_device_tags(self: object, action_name: str, ids: list or str, tags: list or str) -> dict:
         """
         Allows for tagging hosts. If the tags are empty
         """
         _allowed_actions = ["add", "remove"]
         # validate action is allowed AND tags is "something"
         if action_name.lower() in _allowed_actions and tags is not None:
-            operation_id = "UpdateDeviceTags"
-            target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}"
-            header_payload = self.headers
             # convert ids/tags to be a list object if not already
             if isinstance(ids, str):
                 ids = ids.split(",")
@@ -105,91 +100,79 @@ class Hosts(ServiceClass):
                 "device_ids": ids,
                 "tags": patch_tag
             }
-            returned = service_request(caller=self,
-                                       method="PATCH",
-                                       endpoint=target_url,
-                                       body=body_payload,
-                                       headers=header_payload,
-                                       verify=self.ssl_verify
-                                       )
+            returned = process_service_request(
+                calling_object=self,
+                endpoints=Endpoints,
+                operation_id="UpdateDeviceTags",
+                body=body_payload,
+                )
         else:
             returned = generate_error_result("Invalid value specified for action_name parameter.")
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def GetDeviceDetails(self: object, parameters: dict = None, **kwargs) -> dict:
+    def get_device_details(self: object, *args, parameters: dict = None, **kwargs) -> dict:
         """
         Get details on one or more hosts by providing agent IDs (AID).
         You can get a host's agent IDs (AIDs) from the /devices/queries/devices/v1 endpoint,
         the Falcon console or the Streaming API.
         """
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/GetDeviceDetails
-        operation_id = "GetDeviceDetails"
-        target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}".replace("?ids={}", "")
-        header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, Endpoints, operation_id)
-        returned = service_request(caller=self,
-                                   method="GET",
-                                   endpoint=target_url,
-                                   params=parameter_payload,
-                                   headers=header_payload,
-                                   verify=self.ssl_verify
-                                   )
-        return returned
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="GetDeviceDetails",
+            keywords=kwargs,
+            params=handle_single_argument(args, parameters, "ids")
+            )
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def QueryHiddenDevices(self: object, parameters: dict = None, **kwargs) -> dict:
+    def query_hidden_devices(self: object, parameters: dict = None, **kwargs) -> dict:
         """
         Perform the specified action on the Prevention Policies specified in the request.
         """
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/QueryHiddenDevices
-        operation_id = "QueryHiddenDevices"
-        target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}"
-        header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, Endpoints, operation_id)
-        returned = service_request(caller=self,
-                                   method="GET",
-                                   endpoint=target_url,
-                                   params=parameter_payload,
-                                   headers=header_payload,
-                                   verify=self.ssl_verify
-                                   )
-        return returned
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="QueryHiddenDevices",
+            keywords=kwargs,
+            params=parameters
+            )
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def QueryDevicesByFilterScroll(self: object, parameters: dict = None, **kwargs) -> dict:
+    def query_devices_by_filter_scroll(self: object, parameters: dict = None, **kwargs) -> dict:
         """
         Perform the specified action on the Prevention Policies specified in the request.
         """
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/QueryDevicesByFilterScroll
-        operation_id = "QueryDevicesByFilterScroll"
-        target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}"
-        header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, Endpoints, operation_id)
-        returned = service_request(caller=self,
-                                   method="GET",
-                                   endpoint=target_url,
-                                   params=parameter_payload,
-                                   headers=header_payload,
-                                   verify=self.ssl_verify
-                                   )
-        return returned
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="QueryDevicesByFilterScroll",
+            keywords=kwargs,
+            params=parameters
+            )
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def QueryDevicesByFilter(self: object, parameters: dict = None, **kwargs) -> dict:
+    def query_devices_by_filter(self: object, parameters: dict = None, **kwargs) -> dict:
         """
         Search for hosts in your environment by platform, hostname, IP, and other criteria.
         """
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/QueryDevicesByFilter
-        operation_id = "QueryDevicesByFilter"
-        target_url = f"{self.base_url}{[ep[2] for ep in Endpoints if operation_id in ep[0]][0]}"
-        header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, Endpoints, operation_id)
-        returned = service_request(caller=self,
-                                   method="GET",
-                                   endpoint=target_url,
-                                   params=parameter_payload,
-                                   headers=header_payload,
-                                   verify=self.ssl_verify
-                                   )
-        return returned
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="QueryDevicesByFilter",
+            keywords=kwargs,
+            params=parameters
+            )
+    # These method names align to the operation IDs in the API but
+    # do not conform to snake_case / PEP8 and are defined here for
+    # backwards compatibility / ease of use purposes
+    PerformActionV2 = perform_action
+    UpdateDeviceTags = update_device_tags
+    GetDeviceDetails = get_device_details
+    QueryHiddenDevices = query_hidden_devices
+    QueryDevicesByFilterScroll = query_devices_by_filter_scroll
+    QueryDevicesByFilter = query_devices_by_filter
